---
hide:
  - toc
  - navigation
---

!!! tip inline end

    See the navigation links in the header or side-bar.

    Click :octicons-three-bars-16: (top left) on mobile.


# Welcome

Welcome to the [CGSE](https://github.com/IvS-KULeuven/cgse) framework documentation.

[Get started](./getting_started.md){ .md-button .md-button--primary } or go straight to the [Tutorial](./tutorial.md)


## What is the CGSE?

The CGSE is short for Common-EGSE, a framework for managing and running test equipment in a lab. The EGSE stands for 
Electrical Ground Support Equipment, and this includes all equipment that is used to test or calibration an instrument.

- computers: a server running the CGSE and archiving test data and a client to control the test equipment
- temperature controllers: control heaters and monitor temperature sensors
- mechanisms: control mechanisms like hexapods or linear stages 
- optics: control optical equipment like lasers and attenuators
- any other device that can be connected through an Ethernet or USB connection and with a open API.
